## 2.1.0.2 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 2.1.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 2.1.0.0 (2022-12-23)

[stubsabot] Bump flake8-builtins to 2.1.* (#9400)

## 2.0.0.1 (2022-10-15)

Use `Incomplete` instead of `Any` in `__getattr__` (#8903)

## 2.0.0.0 (2022-10-09)

[stubsabot] Bump flake8-builtins to 2.0.* (#8872)

Release: https://pypi.org/pypi/flake8-builtins/2.0.0
Homepage: https://github.com/gforcada/flake8-builtins
Diff: https://github.com/gforcada/flake8-builtins/compare/1.5.3...2.0.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `flake8_builtins.py`.
 - Total lines of Python code added: 338.
 - Total lines of Python code deleted: 546.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 1.5.4 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 1.5.3 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 1.5.1 (2021-12-06)

Mark some fields as ClassVars (#6510)

## 1.5.0 (2021-12-03)

Add stubs for flake8-builtins (#6483)

